@@ -14,9 +14,9 @@ void free_gsl_complex(gsl_complex *c)
   free(c);
 }
 
-gsl_complex *alloc_gsl_complex_float(void)
+gsl_complex_float *alloc_gsl_complex_float(void)
 {
-  gsl_complex *c = malloc(sizeof(gsl_complex_float));
+  gsl_complex_float *c = malloc(sizeof(gsl_complex_float));
   return c;
 }
 
